@@ -4,7 +4,8 @@ from datetime import datetime
 from typing import Tuple
 
 from sidecar.app_instance_identifier import AppInstanceIdentifier
-from sidecar.cloud_logger.logs import ICloudLogger, LogEntry
+from sidecar.cloud_logger.file_logger import ICloudLogger
+from sidecar.cloud_logger.logs import AppLogEntry
 from sidecar.const import DateTimeProvider
 
 
@@ -22,8 +23,8 @@ class AppInstanceEventHandler:
 
     def _write_event_to_cloud_log(self, app_instance_identifier: AppInstanceIdentifier, app_instance_event: str):
         app_instance_log_event = self._create_app_instance_log_event(app_instance_event)
-        log_entry = LogEntry(app=app_instance_identifier.name, instance=app_instance_identifier.infra_id,
-                             topic=self.CloudLoggerEventsTopic, log_events=[app_instance_log_event], log_type="Events")
+        log_entry = AppLogEntry(app=app_instance_identifier.name, instance=app_instance_identifier.infra_id,
+                                topic=self.CloudLoggerEventsTopic, log_events=[app_instance_log_event], log_type="Events")
         self.logger.info(log_entry.get_as_string())
         self._cloud_logger.write(log_entry=log_entry)
 
