@@ -11,9 +11,5 @@ class IAppInstanceIdentifierCreator:
         self._logger = logger
 
     @abstractmethod
-    def create(self, app_name: str, ip_address: str, additional_data: {}) -> AppInstanceIdentifier:
-        raise NotImplementedError
-
-    @abstractmethod
-    def create_from_instance_id(self, app_name: str, instance_id: str) -> AppInstanceIdentifier:
+    def create(self, app_name: str, instance_id: str) -> AppInstanceIdentifier:
         raise NotImplementedError
