@@ -45,16 +45,8 @@ class AppService:
         raise NotImplementedError
 
     @abstractmethod
-    def get_public_dns_name_by_app_name(self, app_name: str, infra_id: str, address_read_timeout: int) -> str:
-        raise NotImplementedError
-
-    @abstractmethod
-    def try_open_firewall_access_to_instances(self, identifier: AppInstanceIdentifier) -> bool:
-        """
-        allows public access to sidecar to the instances
-        :param identifier:
-        :return: whether public access was required
-        """
+    def get_sandbox_gateway_address(self, app_name: str, infra_id: str, address_read_timeout: int,
+                                    internet_facing: bool) -> str:
         raise NotImplementedError
 
     @abstractmethod
@@ -71,12 +63,14 @@ class AzureAppService(AppService):
                  sandbox_id: str,
                  production_id: str,
                  clients_manager: AzureClientsManager,
-                 status_maintainer: AzureStatusMaintainer):
+                 status_maintainer: AzureStatusMaintainer,
+                 env_type: EnvironmentType):
         super().__init__(logger)
         self._sandbox_id = sandbox_id
         self._production_id = production_id
         self._network_client = clients_manager.network_client
         self._status_maintainer = status_maintainer
+        self._env_type = env_type
 
     def update_network_status(self, app_name: str, status: str):
         self._status_maintainer.update_logical_app_healthcheck_status(app_name=app_name, status=status)
@@ -97,10 +91,30 @@ class AzureAppService(AppService):
         else:
             return None
 
-    def get_public_dns_name_by_app_name(self, app_name: str, infra_id: str, address_read_timeout: int) -> str:
-        return Utils.retry_on_exception(func=lambda: self._get_public_ip_from_app_gateway(),
+    def get_sandbox_gateway_address(self, app_name: str, infra_id: str, address_read_timeout: int,
+                                    internet_facing: bool) -> str:
+        if internet_facing:
+            return Utils.retry_on_exception(func=lambda: self._get_public_ip_from_app_gateway(),
+                                            timeout_in_sec=address_read_timeout, logger=self._logger,
+                                            logger_msg="trying to get public dns for app '{}'.".format(app_name))
+
+        return Utils.retry_on_exception(func=lambda: self._get_private_ip_from_app_gateway(),
                                         timeout_in_sec=address_read_timeout, logger=self._logger,
-                                        logger_msg="trying to get public dns for app '{}'.".format(app_name))
+                                        logger_msg="trying to get private ip of application gateway.")
+
+    def _get_private_ip_from_app_gateway(self):
+        rg_name = self._get_app_gateway_resource_group_name()
+        ag = self._network_client.application_gateways.get(resource_group_name=rg_name,
+                                                           application_gateway_name=Const.AG_NAME)
+        ag_frontend_ip_configurations = ag.frontend_ip_configurations
+        if not ag_frontend_ip_configurations:
+            raise Exception(f"App gateway '{ag.name}' has no frontend ip configurations")
+
+        private_ip = ag_frontend_ip_configurations[0].private_ip_address
+        if not private_ip:
+            raise Exception(f"Ip configuration '{ag.frontend_ip_configurations[0].name}' has no private ip address")
+
+        return private_ip
 
     def _get_public_ip_from_app_gateway(self) -> str:
         ag_resource_group = self._get_app_gateway_resource_group_name()
@@ -134,31 +148,32 @@ class AzureAppService(AppService):
     def _get_app_gateway_resource_group_name(self):
         return self._production_id or self._sandbox_id
 
-    def try_open_firewall_access_to_instances(self, identifier: AppInstanceIdentifier) -> bool:
-        return True
-
     def can_access_from_public_address(self, identifier: AppInstanceIdentifier) -> bool:
         # TODO: should return False for ProductionGreen sandbox but only as long as it's green
         #  - hence cannot use env_type from config but instead should take the tag value that is updated on "promote"
-        return True
+        if self._env_type == EnvironmentType.ProductionGreen:
+            return False
+        for route in self._status_maintainer.get_ingress_routes():
+            if route.app_name == identifier.name and \
+                    route.app_port == route.listener_port and \
+                    not route.path and not route.host and \
+                    route.color.lower() == 'blue':
+                return True
+
+        return False
 
 
 class K8sAppService(AppService):
     DNS_RESOLVING_TIMEOUT = 60 * 3  # 3min
 
-    def __init__(self, api: IKubApiService, sandbox_id: str, own_public_ip: str, logger: Logger,
+    def __init__(self, api: IKubApiService, sandbox_id: str, logger: Logger,
                  k8s_status_maintainer: KubStatusMaintainer):
         super().__init__(logger)
         self._k8s_status_maintainer = k8s_status_maintainer
-        self._own_public_ip = own_public_ip
         self.sandbox_id = sandbox_id
         self._api = api
         self._lock = threading.RLock()
 
-    @CallsLogger.wrap
-    def try_open_firewall_access_to_instances(self, identifier: AppInstanceIdentifier) -> bool:
-        return True
-
     @CallsLogger.wrap
     def get_private_dns_name_by_app_name(self, app_name: str, infra_id: str) -> Optional[str]:
         service = self._get_service_of_app(app_name=app_name,
@@ -169,8 +184,9 @@ class K8sAppService(AppService):
         return "{}.{}".format(service['metadata']['name'], self.sandbox_id)
 
     @CallsLogger.wrap
-    def get_public_dns_name_by_app_name(self, app_name: str, infra_id: str, address_read_timeout: int) -> str:
-        dns_name = Utils.retry_on_exception(func=lambda: self._get_public_dns_name_by_app_name(app_name=app_name),
+    def get_sandbox_gateway_address(self, app_name: str, infra_id: str, address_read_timeout: int,
+                                    internet_facing: bool) -> str:
+        dns_name = Utils.retry_on_exception(func=lambda: self._get_ingress_address_by_app_name(app_name=app_name),
                                             timeout_in_sec=address_read_timeout,
                                             logger=self._logger,
                                             logger_msg=f"getting public dns for app '{app_name}'")
@@ -180,7 +196,7 @@ class K8sAppService(AppService):
                                  logger_msg=f"resolving public dns to ip for app '{app_name}'")
         return dns_name
 
-    def _get_public_dns_name_by_app_name(self, app_name: str) -> Optional[str]:
+    def _get_ingress_address_by_app_name(self, app_name: str) -> Optional[str]:
         service = self._get_service_of_app(app_name=app_name,
                                            service_type='LoadBalancer')
         if not service:
@@ -233,7 +249,8 @@ class K8sAppService(AppService):
     def _get_service_of_app(self, app_name: str, service_type: str) -> Optional[dict]:
         services = self._api.get_all_services()
         for service in services:
-            if service['spec']['selector'] == {get_app_selector(app_name): app_name} and service["spec"]["type"] == service_type:
+            if service['spec']['selector'] == {get_app_selector(app_name): app_name} and service["spec"][
+                "type"] == service_type:
                 return service
         return None
 
@@ -248,7 +265,6 @@ class AWSAppService(AppService):
     def __init__(self,
                  session: AwsSession,
                  aws_status_maintainer: AWSStatusMaintainer,
-                 own_public_ip: str,
                  sandbox_id: str,
                  production_id: str,
                  env_type: EnvironmentType,
@@ -259,7 +275,6 @@ class AWSAppService(AppService):
         super().__init__(logger)
         self._aws_status_maintainer = aws_status_maintainer
         self.default_region = default_region
-        self._own_public_ip = own_public_ip
         self._sandbox_id = sandbox_id
         self._production_id = production_id
         self._table_name = table_name
@@ -296,7 +311,7 @@ class AWSAppService(AppService):
             return []
 
     @retry(wait_exponential_multiplier=1000, wait_exponential_max=1000 * 60 * 2,
-           stop_max_delay=1000*60*5, retry_on_result=lambda x: not x)
+           stop_max_delay=1000 * 60 * 5, retry_on_result=lambda x: not x)
     def _get_alb_security_group(self) -> Dict:
         ec2_client = self._session.get_ec2_client()
         if self._production_id:
@@ -320,65 +335,6 @@ class AWSAppService(AppService):
                                                                  "Description"] == self.PUBLIC_PORT_ACCESS]) > 0]
         return permissions
 
-    def _add_permissions_for_sidecar(self, sg_id: str, permissions: List[Dict]):
-        ec2_client = self._session.get_ec2_client()
-        sidecar_public_cidr = "{}/32".format(self._own_public_ip.rstrip('\n'))
-
-        new_permissions = []
-        for permission in permissions:
-            permitted_cidrs = [cidr["CidrIp"] for cidr in permission["IpRanges"]]
-            if sidecar_public_cidr in permitted_cidrs or '0.0.0.0/0' in permitted_cidrs:
-                self._logger.info(f'Sidecar is already allowed to access port {permission["FromPort"]}')
-                continue
-
-            new_permissions.append({'IpProtocol': 'tcp',
-                                    'FromPort': permission["FromPort"],
-                                    'ToPort': permission["ToPort"],
-                                    'IpRanges': [{
-                                        'CidrIp': sidecar_public_cidr,
-                                        'Description': self.PUBLIC_HEALTH_CHECK}]})
-        if new_permissions:
-            self._logger.info(f'Opening ports {[p["FromPort"] for p in new_permissions]} for public healthcheck')
-            ec2_client.authorize_security_group_ingress(
-                GroupId=sg_id,
-                IpPermissions=new_permissions)
-
-    @CallsLogger.wrap
-    def try_open_firewall_access_to_instances(self, identifier: AppInstanceIdentifier) -> bool:
-        # Allowing access from sidecar's public ip to sandbox ALB
-        with self._lock:  # restrict to 1 instance at the time
-
-            # Get instance external ports from DynamoDB
-            external_ports = self._get_instance_external_ports(identifier=identifier)
-            if not external_ports:
-                self._logger.info(f'App "{identifier.name}" does not have external ports')
-                return False
-            else:
-                self._logger.info(f'App "{identifier.name}" have {len(external_ports)} external ports {external_ports}')
-
-            # Get ALB SecurityGroup
-            try:
-                sg = self._get_alb_security_group()
-            except:
-                self._logger.exception(f"Error while getting ALB SecurityGroup for firewall ports {external_ports}")
-                return False
-
-            if not sg:
-                self._logger.error(f'Failed to open firewall ports {external_ports} - ALB SecurityGroup was not found')
-                return False
-
-            # Get the relevant permissions for the current instance ports
-            permissions = self._get_permissions_for_ports(sg=sg, external_ports=external_ports)
-            missing_port_permissions = list(set(external_ports) - set([p['FromPort'] for p in permissions]))
-            if missing_port_permissions:
-                self._logger.error(
-                    f'Failed to open firewall ports {missing_port_permissions} - No matching rules where found for')
-                return False
-
-            # Verify sidecar's public ip has access, and if not, create one
-            self._add_permissions_for_sidecar(sg_id=sg['GroupId'], permissions=permissions)
-            return True
-
     @CallsLogger.wrap
     def get_private_dns_name_by_app_name(self, app_name: str, infra_id: str) -> Optional[str]:
         instance = self._session.get_ec2_resource().Instance(infra_id)
@@ -389,11 +345,12 @@ class AWSAppService(AppService):
             return None
 
     @CallsLogger.wrap
-    def get_public_dns_name_by_app_name(self, app_name: str, infra_id: str, address_read_timeout: int) -> str:
-        return Utils.retry_on_exception(func=lambda: self._get_public_dns_name_by_instance_id(instance_id=infra_id),
+    def get_sandbox_gateway_address(self, app_name: str, infra_id: str, address_read_timeout: int,
+                                    internet_facing: bool) -> str:
+        return Utils.retry_on_exception(func=lambda: self._get_sandbox_alb_dns(instance_id=infra_id),
                                         timeout_in_sec=address_read_timeout,
                                         logger=self._logger,
-                                        logger_msg="trying to get public dns for app '{}'.".format(app_name))
+                                        logger_msg="trying to get sandbox gateway dns for app '{}'.".format(app_name))
 
     @CallsLogger.wrap
     def can_access_from_public_address(self, identifier: AppInstanceIdentifier) -> bool:
@@ -422,10 +379,7 @@ class AWSAppService(AppService):
             raise Exception("dynamodb table is not ready yet")
         return table, item["Item"]
 
-    def _get_public_dns_name_by_instance_id(self, instance_id: str):
+    def _get_sandbox_alb_dns(self, instance_id: str):
         instance = self._session.get_ec2_resource().Instance(instance_id)
         dns = AwsTagHelper.wait_for_tags(instance, self._logger).get(Const.EXTERNAL_ELB_DNS_NAME)
-        if dns:
-            return dns
-
-        return instance.public_dns_name
+        return dns
