@@ -4,14 +4,17 @@ from typing import List
 import datetime
 
 from sidecar.app_instance_identifier import AppInstanceIdentifier
+from sidecar.aws_instance_states import AwsInstanceStates
 from sidecar.aws_session import AwsSession
 from sidecar.aws_tag_helper import AwsTagHelper
 from sidecar.const import Const
 from sidecar.app_instance_service import IAppInstanceService, StaleAppInstanceException
 from sidecar.aws_status_maintainer import AWSStatusMaintainer
+from sidecar.sandbox_error import SandboxError
 
 
 class AwsAppInstanceService(IAppInstanceService):
+
     def __init__(self, sandbox_id: str, logger: Logger, aws_session: AwsSession,
                  aws_status_maintainer: AWSStatusMaintainer):
         super().__init__(logger)
@@ -19,17 +22,15 @@ class AwsAppInstanceService(IAppInstanceService):
         self.sandbox_id = sandbox_id
         self.aws_status_maintainer = aws_status_maintainer
 
-    def _update_app_status(self, instance_id: str, app_name: str, status: str):
-        instance = self._get_existing_instance(instance_id, app_name)
-        # should update status only for a "live" instance
-        if not self._is_instance_part_of_sandbox(instance):
-            raise StaleAppInstanceException("cannot update '{APP_NAME}' status to '{STATUS}' since the app instance is "
-                                            "no longer a part of the sandbox. infra id: {INFRA_ID}"
-                                            .format(APP_NAME=app_name, STATUS=status, INFRA_ID=instance_id))
+    def get_deployment_outputs(self, app_name: str) -> {}:
+        return self.aws_status_maintainer.get_app_deployment_outputs(app_name)
 
-        instance_logical_id = AwsTagHelper.safely_get_tag(instance, Const.INSTANCELOGICALID, self._logger)
-        self.aws_status_maintainer.update_app_instance_status(instance_logical_id, instance_id, app_name,
-                                                              Const.APP_STATUS_TAG, status)
+    def is_qualiy_off(self) -> bool:
+        instance = self._get_qualiy_instance()
+        if not instance:
+            raise Exception('QualiY instance was not found')
+
+        return instance.state["Name"] in [AwsInstanceStates.STOPPED, AwsInstanceStates.TERMINATED]
 
     def _get_existing_instance(self, instance_id: str, app_name: str):
         instance = self._get_instance_by_id(instance_id)
@@ -38,11 +39,71 @@ class AwsAppInstanceService(IAppInstanceService):
                             .format(APP_NAME=app_name, INSTANCE_ID=instance_id))
         return instance
 
-    def update_status_if_not_stale(self, app_instance_identifier: AppInstanceIdentifier, status: str):
-        instance_id = app_instance_identifier.infra_id
-        self._update_app_status(instance_id, app_instance_identifier.name, status)
+    def get_public_address(self, app_instance_identifier: AppInstanceIdentifier) -> str:
+        instance = self._get_existing_instance(instance_id=app_instance_identifier.infra_id,
+                                               app_name=app_instance_identifier.name)
+        alb_dns = next((tag['Value'] for tag in instance.tags if tag['Name'] == Const.EXTERNAL_ELB_DNS_NAME), None)
+        return alb_dns
 
-    def check_which_exist(self, identifiers: List[AppInstanceIdentifier])-> List[AppInstanceIdentifier]:
+    def update_status_if_not_stale(self, app_instance_identifier: AppInstanceIdentifier, status: str):
+        instance_logical_id = self._get_live_instance_logical_id(app_instance_identifier)
+
+        self.aws_status_maintainer.update_app_instance_healthcheck_status(
+            instance_logical_id=instance_logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            status=status)
+
+    def update_artifacts_status(self, app_instance_identifier: AppInstanceIdentifier, status: str):
+        instance_logical_id = self._get_live_instance_logical_id(app_instance_identifier)
+
+        self.aws_status_maintainer.update_app_instance_artifacts_status(
+            instance_logical_id=instance_logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            status=status)
+
+    def update_configuration_status(self, app_instance_identifier: AppInstanceIdentifier, status: str):
+        instance_logical_id = self._get_live_instance_logical_id(app_instance_identifier)
+
+        self.aws_status_maintainer.update_app_instance_configuration_status(
+            instance_logical_id=instance_logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            status=status)
+
+    def update_deployment_outputs(self, app_instance_identifier: AppInstanceIdentifier, outputs: {}):
+        instance_logical_id = self._get_live_instance_logical_id(app_instance_identifier)
+
+        self.aws_status_maintainer.update_app_instance_outputs(
+            instance_logical_id=instance_logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            outputs=outputs)
+
+    def add_error(self, app_instance_identifier: AppInstanceIdentifier, error: SandboxError):
+        instance_logical_id = self._get_live_instance_logical_id(app_instance_identifier)
+
+        self.aws_status_maintainer.add_app_instance_error(
+            instance_logical_id=instance_logical_id,
+            instance_id=app_instance_identifier.infra_id,
+            app_name=app_instance_identifier.name,
+            error=error)
+
+    def _get_live_instance_logical_id(self, app_instance_identifier: AppInstanceIdentifier) -> str:
+        instance_id = app_instance_identifier.infra_id
+        app_name = app_instance_identifier.name
+
+        instance = self._get_existing_instance(instance_id, app_name)
+        # should update status only for a "live" instance
+        if not self._is_instance_part_of_sandbox(instance):
+            raise StaleAppInstanceException(f"Cloud not get '{app_name}' logical id since the app "
+                                            f"instance is no longer a part of the sandbox. infra id: {instance_id}")
+
+        instance_logical_id = AwsTagHelper.wait_for_tag(instance, Const.INSTANCELOGICALID, self._logger)
+        return instance_logical_id
+
+    def check_which_exist(self, identifiers: List[AppInstanceIdentifier]) -> List[AppInstanceIdentifier]:
         instance_ids = list(set(identifier.infra_id for identifier in identifiers))
         instances = self._get_sandbox_app_instances_by_ids(instance_ids=instance_ids)
 
@@ -56,6 +117,16 @@ class AwsAppInstanceService(IAppInstanceService):
         ec2 = self.aws_session.get_ec2_resource()
         return ec2.Instance(instance_id)
 
+    def _get_qualiy_instance(self):
+        ec2 = self.aws_session.get_ec2_resource()
+
+        filters = [{'Name': 'tag:' + Const.SANDBOX_ID_TAG,
+                    'Values': [self.sandbox_id]},
+                   {'Name': 'tag:' + Const.APP_NAME_TAG,
+                    'Values': [Const.QUALY_SERVICE_NAME]}]
+        instance = next(iter(list(ec2.instances.filter(Filters=filters))), None)
+        return instance
+
     def _is_instance_part_of_sandbox(self, instance) -> bool:
         instance_as_list = [instance]
         self._filter_out_autoscaling_instances_not_in_asg(instance_as_list)
@@ -100,7 +171,7 @@ class AwsAppInstanceService(IAppInstanceService):
     def _get_asg_name_to_instances_map(self, instances):
         asg_name_to_instances_map = dict()
         for instance in instances:
-            asg_tag_value = AwsTagHelper.safely_get_tag(instance, AwsTagHelper.AutoScalingGroupNameTag, self._logger)
+            asg_tag_value = AwsTagHelper.wait_for_tags(instance, self._logger).get(AwsTagHelper.AutoScalingGroupNameTag)
             if asg_tag_value:
                 asg_instances_list = asg_name_to_instances_map.setdefault(asg_tag_value, [])
                 asg_instances_list.append(instance)
@@ -122,10 +193,10 @@ class AwsAppInstanceService(IAppInstanceService):
         return autoscaling_groups
 
     def _create_app_instance_identifiers(self, instance) -> List[AppInstanceIdentifier]:
-        instance_logical_id = AwsTagHelper.safely_get_tag(instance, Const.INSTANCELOGICALID, self._logger)
-        all_app_names = self.aws_status_maintainer.getAllappNamesForInstance(instance_logical_id)
+        instance_logical_id = AwsTagHelper.wait_for_tag(instance, Const.INSTANCELOGICALID, self._logger)
+        all_app_names = self.aws_status_maintainer.get_all_app_names_for_instance(instance_logical_id)
         return [AppInstanceIdentifier(name=app_name, infra_id=instance.instance_id) for app_name in all_app_names]
 
     def _is_infra_instance(self, instance) -> bool:
-        app_name_tag_value = AwsTagHelper.safely_get_tag(instance, Const.APP_NAME_TAG, self._logger)
-        return app_name_tag_value == Const.AWS_SIDECAR_APP_NAME or app_name_tag_value == Const.QUALY_SERVICE_NAME
+        app_name_tag_value = AwsTagHelper.wait_for_tag(instance, Const.APP_NAME_TAG, self._logger)
+        return app_name_tag_value in [Const.AWS_SIDECAR_APP_NAME, Const.QUALY_SERVICE_NAME]
