@@ -100,8 +100,5 @@ class AwsSession:
         return self._sandbox_stack_name
 
     @property
-    def production_infra_stack_name(self) -> Optional[str]:
-        if self.aws_config.production_id:
-            return f'production-{self.aws_config.production_id}'
-        else:
-            return None
+    def alb_stack_name(self) -> Optional[str]:
+        return self.aws_config.infra_stack_name
