@@ -6,7 +6,7 @@ from typing import List
 from sidecar.aws_session import AwsSession
 from sidecar.const import Const
 from sidecar.utils import Utils
-from sidecar.status_maintainer import StatusMaintainer
+from sidecar.status_maintainer import StatusMaintainer, IngressRouteRequest
 from sidecar.sandbox_error import SandboxError
 
 
@@ -360,7 +360,7 @@ class AWSStatusMaintainer(StatusMaintainer):
         return not response.get("ResponseMetadata") and \
                not response.get("ResponseMetadata").get("HTTPStatusCode") == 200
 
-    def get_ingress_routes(self) -> List['IngressRouteRequest']:
+    def get_ingress_routes(self) -> List[IngressRouteRequest]:
         items = []
         for ingress_route in self.table_data.get('ingress_routes', []):
             items.append(IngressRouteRequest(
@@ -387,13 +387,3 @@ class AWSStatusMaintainer(StatusMaintainer):
                 return doc['terminating']
 
         return False
-
-
-class IngressRouteRequest:
-    def __init__(self, listener_port: int, path: str, host: str, app_port: int, app_name: str, color: str):
-        self.listener_port = listener_port
-        self.path = path
-        self.host = host
-        self.app_port = app_port
-        self.app_name = app_name
-        self.color = color
