@@ -1,7 +1,8 @@
 from azure.mgmt.compute import ComputeManagementClient
 from azure.mgmt.cosmosdb import CosmosDB
 from azure.mgmt.network import NetworkManagementClient
-from msrestazure.azure_active_directory import ServicePrincipalCredentials
+from msrest.authentication import BasicTokenAuthentication
+from msrestazure.azure_active_directory import MSIAuthentication, ServicePrincipalCredentials
 from azure.mgmt.storage import StorageManagementClient
 from azure.cosmosdb.table import TableService
 
@@ -9,24 +10,28 @@ from azure.cosmosdb.table import TableService
 class AzureCredentialsProvider:
 
     def __init__(self, management_resource_group: str, subscription_id: str, application_id: str,
-                 application_secret: str, tenant_id: str):
+                 application_secret: str, tenant_id: str, managed_identity_client_id):
         self.management_resource_group = management_resource_group
         self.subscription_id = subscription_id
         self.application_id = application_id
         self.application_key = application_secret
         self.tenant = tenant_id
+        self._managed_identity_client_id = managed_identity_client_id
 
-    def get_service_principal(self):
-        return ServicePrincipalCredentials(client_id=self.application_id,
-                                           secret=self.application_key,
-                                           tenant=self.tenant)
+    def get_credentials(self) -> BasicTokenAuthentication:
+        # fallback for backwards compatibility
+        if not self._managed_identity_client_id:
+            return ServicePrincipalCredentials(client_id=self.application_id,
+                                               secret=self.application_key,
+                                               tenant=self.tenant)
+        return MSIAuthentication(client_id=self._managed_identity_client_id)
 
 
 class AzureClientsManager:
 
     def __init__(self, credentials_provider: AzureCredentialsProvider):
         self._credentials_provider = credentials_provider
-        self._service_principal = self._credentials_provider.get_service_principal()
+        self._credentials = self._credentials_provider.get_credentials()
         self._cosmos_client = None
         self._compute_client = None
         self._table_service = None
@@ -40,26 +45,26 @@ class AzureClientsManager:
     @property
     def network_client(self):
         if self._network_client is None:
-            self._network_client = NetworkManagementClient(self._service_principal, self._credentials_provider.subscription_id)
+            self._network_client = NetworkManagementClient(self._credentials, self._credentials_provider.subscription_id)
         return self._network_client
 
     @property
     def cosmos_db_client(self):
         if self._cosmos_client is None:
-            self._cosmos_client = CosmosDB(self._service_principal, self._credentials_provider.subscription_id)
+            self._cosmos_client = CosmosDB(self._credentials, self._credentials_provider.subscription_id)
         return self._cosmos_client
 
     @property
     def compute_client(self):
         if self._compute_client is None:
-            self._compute_client = ComputeManagementClient(self._service_principal,
+            self._compute_client = ComputeManagementClient(self._credentials,
                                                            self._credentials_provider.subscription_id)
         return self._compute_client
 
     @property
     def storage_client(self):
         if self._storage_client is None:
-            self._storage_client = StorageManagementClient(self._service_principal,
+            self._storage_client = StorageManagementClient(self._credentials,
                                                            self._credentials_provider.subscription_id)
         return self._storage_client
 
