@@ -8,7 +8,7 @@ from retrying import retry
 from sidecar.azure_clp.data_store_service import DataStoreService
 from sidecar.azure_clp.retrying_helpers import retry_if_connection_error, retry_if_result_none_or_empty
 from sidecar.const import Const
-from sidecar.status_maintainer import StatusMaintainer
+from sidecar.status_maintainer import StatusMaintainer, IngressRouteRequest
 from logging import Logger
 from sidecar.sandbox_error import SandboxError
 
@@ -20,6 +20,7 @@ class AzureStatusMaintainer(StatusMaintainer):
     INSTANCES_KEY = "instances"
     ROOT_SERVICES_KEY = "services"
     ROOT_LOGICAL_APPS_KEY = "logical-apps"
+    ROOT_INGRESS_ROUTES_KEY = "ingress_routes"
 
     def __init__(self, data_store_service: DataStoreService, sandbox_id: str, logger: Logger):
         super().__init__(logger)
@@ -46,6 +47,7 @@ class AzureStatusMaintainer(StatusMaintainer):
         self._cached_spec = sandbox_document[self.ROOT_SPEC_KEY]
         self._cached_logical_apps = sandbox_document.get(self.ROOT_LOGICAL_APPS_KEY, {})
         self._cached_sandbox_errors = sandbox_document.get(Const.SANDBOX_ERRORS)
+        self._cached_ingress_routes = sandbox_document.get(self.ROOT_INGRESS_ROUTES_KEY, {})
 
     @retry(stop_max_attempt_number=5, wait_fixed=1000, retry_on_result=retry_if_result_none_or_empty,
            retry_on_exception=retry_if_connection_error)
@@ -203,3 +205,15 @@ class AzureStatusMaintainer(StatusMaintainer):
             if app_name in logical_details[Const.INTERNAL_PORTS]:
                 return logical_details[Const.INTERNAL_PORTS][app_name]
         return []
+
+    def get_ingress_routes(self) -> List[IngressRouteRequest]:
+        items = []
+        for ingress_route in self._cached_ingress_routes:
+            items.append(IngressRouteRequest(
+                listener_port=int(ingress_route['listener_port']),
+                path=ingress_route['path'],
+                host=ingress_route['host'],
+                app_name=ingress_route['app_name'],
+                app_port=int(ingress_route['app_port']),
+                color=ingress_route['color']))
+        return items
