@@ -4,9 +4,10 @@ from inspect import getmembers, isclass, isabstract
 from logging import Logger
 
 from sidecar.aws_session import AwsSession
+from sidecar.cloud_logger.file_logger import ICloudLogger
 from sidecar.model.objects import ISidecarConfiguration
 from .. import cloud_logger
-from . import ICloudLogger, FileLogger
+from . import FileLogger
 
 
 class CloudLoggerFactory(object):
