@@ -113,9 +113,11 @@ class Const:
     INTERNAL_PORTS = _get_tag_name('internal-ports')
     MAIN_ALB = "MainALB"
     MAIN_ALB_SG = 'MainALBSG'
+    AG_NAME = 'ag'
     AG_PUBLIC_IP = 'ag_pub_ip'
 
-    SERVICE_EXECUTION_POD = _get_tag_name('service-execution-pod')
+    SERVICE_EXECUTION_POD_NAME = _get_tag_name('service-execution-pod')
+    SERVICE_TERMINATION_POD_NAME = _get_tag_name('service-termination')
 
     @staticmethod
     def get_config_file():
