@@ -3,11 +3,16 @@ import os
 import platform
 import socket
 
-from sidecar.model.objects import ISidecarConfiguration
+
+class LogConfigData:
+    def __init__(self, environment: str, sandbox_id: str, production_id: str):
+        self.environment = environment
+        self.sandbox_id = sandbox_id
+        self.production_id = production_id
 
 
 class LoggingFilter(logging.Filter):
-    def __init__(self, config: ISidecarConfiguration):
+    def __init__(self, config: LogConfigData):
         logging.Filter.__init__(self)
         self.config = config
 
