@@ -6,7 +6,7 @@ from typing import List
 from sidecar.app_instance_identifier import AppInstanceIdentifier
 from sidecar.app_services.app_service import AppService
 from sidecar.apps_configuration_end_tracker import AppsConfigurationEndTracker, AppConfigurationEndStatus
-from sidecar.const import AppNetworkStatus
+from sidecar.const import AppNetworkStatus, Const
 from sidecar.health_check.app_health_check_configuration import AppHealthCheckConfiguration
 from sidecar.health_check.app_health_check_state import AppHealthCheckState
 from sidecar.health_check.health_check_executor import HealthCheckExecutor
@@ -25,7 +25,8 @@ class AppHealthCheckMonitor:
                  app_service: AppService,
                  health_check_configuration: AppHealthCheckConfiguration,
                  apps_configuration_end_tracker: AppsConfigurationEndTracker,
-                 logger: Logger):
+                 logger: Logger,
+                 internet_facing: bool = True):
         self._apps = apps
         self._health_check_configuration = health_check_configuration
         self._apps_configuration_end_tracker = apps_configuration_end_tracker
@@ -34,12 +35,18 @@ class AppHealthCheckMonitor:
         self._executor = executor
         self._app_service = app_service
         self._logger = logger
+        self.internet_facing = internet_facing
         self._lock = threading.RLock()
 
     @CallsLogger.wrap
     def start(self, identifier: AppInstanceIdentifier):
         try:
             app_configuration_status = self._get_app_configuration_status(identifier)
+
+            if app_configuration_status \
+                    and app_configuration_status.is_ended_with_status(AppConfigurationEndStatus.ERROR):
+                self._update_status(app_name=identifier.name, status=AppNetworkStatus.ERROR)
+
             if app_configuration_status \
                     and app_configuration_status.is_ended_with_status(AppConfigurationEndStatus.COMPLETED):
                 self._start(identifier=identifier)
@@ -65,6 +72,7 @@ class AppHealthCheckMonitor:
             check_public = self._app_service.can_access_from_public_address(identifier=identifier) and \
                            any([app for app in self._apps if app.name == identifier.name and app.has_public_access])
             if check_public:
+                self._logger.info(f"Starting public health check on {identifier.name}")
                 self._test_public_network(identifier=identifier)
             else:
                 self._update_status(app_name=identifier.name, status=AppNetworkStatus.COMPLETED)
@@ -78,22 +86,20 @@ class AppHealthCheckMonitor:
         self._update_status(app_name=identifier.name, status=AppNetworkStatus.TESTING_PUBLIC_NETWORK)
 
         try:
-            opened = self._app_service.try_open_firewall_access_to_instances(identifier=identifier)
+            address = self._app_service.get_sandbox_gateway_address(app_name=identifier.name,
+                                                                     infra_id=identifier.infra_id,
+                                                                     address_read_timeout=timeout,
+                                                                     internet_facing=self.internet_facing)
 
-            if opened:
-                dns_name = self._app_service.get_public_dns_name_by_app_name(app_name=identifier.name,
-                                                                             infra_id=identifier.infra_id,
-                                                                             address_read_timeout=timeout)
+            self._logger.info(f"Start _test_sandbox_gateway_network with dns_name = {address}")
 
-                dns_check = self._health_check_dns_names(identifier=identifier,
-                                                         dns_name=dns_name)
-                if dns_check:
-                    status = AppNetworkStatus.COMPLETED
-                else:
-                    status = AppNetworkStatus.ERROR
-                    self._add_public_healthcheck_error(app_name=identifier.name)
-            else:
+            dns_check = self._health_check_dns_names(identifier=identifier,
+                                                     dns_name=address)
+            if dns_check:
                 status = AppNetworkStatus.COMPLETED
+            else:
+                status = AppNetworkStatus.ERROR
+                self._add_public_healthcheck_error(app_name=identifier.name)
 
             self._update_status(app_name=identifier.name, status=status)
         except Exception as ex:
@@ -132,4 +138,7 @@ class AppHealthCheckMonitor:
         cmd = self._preparer.prepare(app_name=identifier.name,
                                      address=dns_name)
 
-        return self._executor.start(identifier=identifier, cmd=cmd)
+        if not cmd:
+            return True
+
+        return self._executor.start(identifier=identifier, cmd=cmd, address=dns_name)
