@@ -55,5 +55,9 @@ class AppInstanceHealthCheckMonitor:
         cmd = self._preparer.prepare(app_name=identifier.name,
                                      address=ip_address)
 
+        if not cmd:
+            return True
+
         return self._executor.start(identifier=identifier,
-                                    cmd=cmd)
+                                    cmd=cmd,
+                                    address=ip_address)
