@@ -3,7 +3,7 @@ import signal
 import subprocess
 from datetime import datetime
 from logging import Logger
-from typing import List
+from typing import List, Dict
 
 from sidecar.app_instance_identifier import IIdentifier
 from sidecar.health_check.health_check_executor_logger import HealthCheckExecutorLogger
@@ -31,8 +31,16 @@ class HealthCheckExecutor:
         self._domain_name = f'{sandbox_id}.sandbox.com'
         self._sandbox_public_address_fetcher = sandbox_public_address_fetcher
 
+    @staticmethod
+    def _set_or_concat_env(dic: Dict[str, str], key: str, val: str):
+        if key in dic:
+            if dic[key]:
+                val = f'{val},{dic[key]}'
+
+        dic[key] = val
+
     @CallsLogger.wrap
-    def start(self, identifier: IIdentifier, cmd: List[str]) -> bool:
+    def start(self, identifier: IIdentifier, cmd: List[str], address: str) -> bool:
 
         app = next(iter([app for app in self._apps if app.name == identifier.name]), None)  # type: SidecarApplication
 
@@ -42,11 +50,15 @@ class HealthCheckExecutor:
 
         env = {**os.environ, **resolved_inputs}
 
+        # should not use proxy when running healthcheck
+        self._set_or_concat_env(env, 'NO_PROXY', address)
+        self._set_or_concat_env(env, 'no_proxy', address)
+
         try:
             sandbox_publie_address = self._sandbox_public_address_fetcher.get_value() if self._sandbox_public_address_fetcher else ''
         except:
             sandbox_publie_address = ''
-            
+
         env.update({
             'DOMAIN_NAME': self._domain_name,
             'SANDBOX_ID': self._sandbox_id,
@@ -55,10 +67,14 @@ class HealthCheckExecutor:
             'COLONY_SANDBOX_ID': self._sandbox_id,
             'COLONY_PUBLIC_ADDRESS': sandbox_publie_address})
 
+        # todo shayk should delete these lines before going to production
+        # self._logger.info(f'running healthcheck: {identifier.name} envs: {env}')
+        # print(f'running healthcheck: {identifier.name} envs: {env}')
+
         start = datetime.now()
         timed_out = False
         read_interval = 0.5
-        
+
         """
         run healthcheck command in subprocess and redirect its outputs to subprocess' stdout
         read stdout line by line until subprocess ended or until timeout and send it to cloud logger
@@ -72,8 +88,10 @@ class HealthCheckExecutor:
                               universal_newlines=True,
                               env=env) as p:
             try:
-                stdout_stream_reader = NonBlockingStreamReader(stream=p.stdout, interval=read_interval)
-                stderr_stream_reader = NonBlockingStreamReader(stream=p.stderr, interval=read_interval)
+                stdout_stream_reader = NonBlockingStreamReader(stream=p.stdout, interval=read_interval,
+                                                               logger=self._logger)
+                stderr_stream_reader = NonBlockingStreamReader(stream=p.stderr, interval=read_interval,
+                                                               logger=self._logger)
                 self._logger.info('running command {0}'.format(cmd))
 
                 while True:
@@ -97,6 +115,9 @@ class HealthCheckExecutor:
                         stdout_stream_reader.stop()
                         stderr_stream_reader.stop()
 
+                        stdout_stream_reader.drain_stream()
+                        stderr_stream_reader.drain_stream()
+
                         for line in stdout_stream_reader.read_lines():
                             self._executor_logger.log_line(line, identifier)
 
@@ -114,6 +135,7 @@ class HealthCheckExecutor:
                 process_exit_code = p.returncode
                 if process_exit_code == 0:
                     self._executor_logger.log_success(identifier=identifier)
+                    self._logger.info("Successfully done health check")
                     return True
                 else:
                     self._executor_logger.log_error(identifier=identifier, exit_code=process_exit_code)
@@ -127,6 +149,7 @@ class HealthCheckExecutor:
                     resolved_inputs[k] = self._input_resolver.resolve(v)
                 else:
                     resolved_inputs[k] = v
+                resolved_inputs[k] = "" if resolved_inputs[k] is None else resolved_inputs[k]
         return resolved_inputs
 
     def _kill_process(self, process):
