@@ -5,10 +5,15 @@ from sidecar.const import Const
 
 
 class KubApiPodReader:
+
     @staticmethod
     def get_pod_name(pod: {}) -> str:
         return pod['metadata']['name']
 
+    @staticmethod
+    def is_services_related_pod(pod: {}):
+        return pod['metadata']['name'] in [Const.SERVICE_EXECUTION_POD_NAME, Const.SERVICE_TERMINATION_POD_NAME]
+
     @staticmethod
     def is_pod_ended(pod):
         return KubApiPodReader.get_pod_phase(pod) in ["Failed", "Succeeded"]
