@@ -19,10 +19,6 @@ class IKubApiService(metaclass=ABCMeta):
     def get_all_pods_list(self, include_infra: bool = True, include_ended=True, include_terminating: bool = True) -> []:
         raise NotImplementedError
 
-    @abstractmethod
-    def try_get_pod_json_by_ip(self, ip_address: str) -> {}:
-        raise NotImplementedError
-
     @abstractmethod
     def try_get_pod_json_by_container_id(self, container_id: str) -> {}:
         raise NotImplementedError
@@ -47,6 +43,13 @@ class IKubApiService(metaclass=ABCMeta):
     def get_all_services(self) -> {}:
         raise NotImplementedError
 
+    def get_pod_by_name(self, name: str) -> {}:
+        raise NotImplementedError()
+
+    @abstractmethod
+    def get_annotation(self, name: str):
+        pass
+
 
 class KubApiService(IKubApiService):
     def __init__(self,
@@ -61,6 +64,47 @@ class KubApiService(IKubApiService):
         self._disable_secure_warnings()
         self.token = kub_token_provider.get_token()
 
+    def get_annotation(self, name: str):
+        s = self._get_session()
+        s.headers['Content-Type'] = 'application/strategic-merge-patch+json'
+        url = "{HOSTNAME}/api/v1/namespaces/{NAMESPACE}".format(
+            HOSTNAME=self.hostname,
+            NAMESPACE=self.namespace
+        )
+        try:
+            res = s.get(url=url, verify=False)
+            res.raise_for_status()
+            namespace_jason = res.json()
+
+            annotation_value = namespace_jason["metadata"]["annotations"].get(name, "")
+
+            return annotation_value
+
+        except Exception as exc:
+            self.logger.exception("Got exception while getting annotation {key}, message: {message}".format(
+                key=name,
+                message=str(exc)))
+            raise exc
+
+    def get_pod_by_name(self, name: str) -> str:
+        s = self._get_session()
+        s.headers['Content-Type'] = 'application/strategic-merge-patch+json'
+        url = "{HOSTNAME}/api/v1/namespaces/{NAMESPACE}/pods/{POD}".format(
+            HOSTNAME=self.hostname,
+            NAMESPACE=self.namespace,
+            POD=name
+        )
+
+        try:
+            res = s.get(url=url, verify=False)
+            res.raise_for_status()
+            return res.json()
+        except Exception as exc:
+            self.logger.exception("Got exception while getting pod {pod}, message: {message}".format(
+                pod=name,
+                message=str(exc)))
+            raise exc
+
     def get_all_pods_list(self, include_infra: bool = True, include_ended=True, include_terminating: bool = True) -> []:
         s = self._get_session()
         s.headers['Content-Type'] = 'application/strategic-merge-patch+json'
@@ -85,12 +129,6 @@ class KubApiService(IKubApiService):
                                           include_terminating=include_terminating)
         return live_app_pods
 
-    def try_get_pod_json_by_ip(self, ip_address: str) -> {}:
-        # when we're looking for a specific pod, we want to find it no matter in what state it is
-        pods = self.get_all_pods_list()
-        pod_json = next(iter([pod for pod in pods if KubApiPodReader.safely_get_pod_ip(pod) == ip_address]), None)
-        return pod_json
-
     def try_get_pod_json_by_container_id(self, container_id: str) -> {}:
         # when we're looking for a specific pod, we want to find it no matter in what state it is
         pods = self.get_all_pods_list()
