@@ -77,7 +77,7 @@ class KubAppInstanceService(IAppInstanceService):
         pods = self.kub_api_service.get_all_pods_list(include_infra=False, include_ended=False,
                                                       include_terminating=False)
         # only applications pods
-        return [p for p in pods if KubApiPodReader.get_pod_name(p) != Const.SERVICE_EXECUTION_POD]
+        return [p for p in pods if not KubApiPodReader.is_services_related_pod(p)]
 
     def _create_app_instance_identifiers(self, pod_json: dict()) -> List[AppInstanceIdentifier]:
         apps_info_json = KubApiPodReader.get_apps_info_json(pod_json)
