@@ -21,7 +21,8 @@ class KubSandboxStartTimeUpdater(ISandboxStartTimeUpdater):
         self.kub_api_service = kub_api_service
         self.date_time_provider = date_time_provider
 
-    def _on_health_check_done(self):
+    def _on_deployment_complete(self):
         time = str(self.date_time_provider.get_current_time_utc())
         annotations = {Const.SANDBOX_START_TIME: time, Const.SANDBOX_START_TIME_v2: time}
         self.kub_api_service.update_namespace(annotations)
+
