@@ -198,7 +198,8 @@ class ISidecarConfiguration(metaclass=ABCMeta):
                  apps: List[SidecarApplication],
                  services: List[ISidecarService],
                  messaging: MessagingConnectionProperties,
-                 env_type: str):
+                 env_type: str,
+                 internet_facing: bool = True):
         self.messaging = messaging
         self.apps = apps
         self.services = services
@@ -209,15 +210,13 @@ class ISidecarConfiguration(metaclass=ABCMeta):
         self.environment = environment
         self.cloud_external_key = cloud_external_key
         self.env_type = EnvironmentType(env_type)
+        self.internet_facing = internet_facing
 
 
 class AzureSidecarConfiguration(ISidecarConfiguration):
     def __init__(self,
                  management_resource_group: str,
                  subscription_id: str,
-                 application_id: str,
-                 application_secret: str,
-                 tenant_id: str,
                  environment: str,
                  sandbox_id: str,
                  production_id: str,
@@ -227,16 +226,23 @@ class AzureSidecarConfiguration(ISidecarConfiguration):
                  services: List[ISidecarService],
                  messaging: MessagingConnectionProperties,
                  env_type: str,
-                 vnet_name: str):
+                 vnet_name: str,
+                 application_id: str = None,
+                 application_secret: str = None,
+                 tenant_id: str = None,
+                 managed_identity_client_id: str = None,
+                 internet_facing: bool = True):
         super().__init__(environment, "azure", sandbox_id, production_id, space_id, cloud_external_key, apps, services,
                          messaging,
-                         env_type)
+                         env_type,
+                         internet_facing)
         self.tenant_id = tenant_id
         self.application_secret = application_secret
         self.application_id = application_id
         self.subscription_id = subscription_id
         self.management_resource_group = management_resource_group
         self.vnet_name = vnet_name
+        self.managed_identity_client_id = managed_identity_client_id
 
     def __eq__(self, other):
         if isinstance(self, other.__class__):
@@ -251,7 +257,8 @@ class AzureSidecarConfiguration(ISidecarConfiguration):
                    self.cloud_external_key == other.cloud_external_key and \
                    self.apps == other.apps and \
                    self.messaging == other.messaging and \
-                   self.vnet_name == other.vnet_name
+                   self.vnet_name == other.vnet_name and \
+                   self.managed_identity_client_id == other.managed_identity_client_id
         return False
 
     def __repr__(self):
@@ -259,8 +266,10 @@ class AzureSidecarConfiguration(ISidecarConfiguration):
                "subscription_id={} " \
                "application_id={} " \
                "tenant_id={} " \
+               "managed_identity_client_id={} " \
                "environment={} " \
                "provider={} " \
+               "internet_facing={} " \
                "sandbox_id={} " \
                "production_id={} " \
                "space_id={} " \
@@ -272,8 +281,10 @@ class AzureSidecarConfiguration(ISidecarConfiguration):
                                      self.subscription_id,
                                      self.application_id,
                                      self.tenant_id,
+                                     "has value" if self.managed_identity_client_id else "empty",
                                      self.environment,
                                      self.provider,
+                                     self.internet_facing,
                                      self.sandbox_id,
                                      self.production_id,
                                      self.space_id,
@@ -298,10 +309,14 @@ class AwsSidecarConfiguration(ISidecarConfiguration):
                  messaging: MessagingConnectionProperties,
                  env_type: str,
                  data_table_name: str,
-                 onboarding_region: str = None):
+                 infra_stack_name: str,
+                 onboarding_region: str = None,
+                 internet_facing: bool = True):
         super().__init__(environment, "aws", sandbox_id, production_id, space_id, cloud_external_key, apps, services,
                          messaging,
-                         env_type)
+                         env_type,
+                         internet_facing)
+        self.infra_stack_name = infra_stack_name
         self.onboarding_region = onboarding_region
         self.region_name = region_name
         self.data_table_name = data_table_name
@@ -326,6 +341,7 @@ class AwsSidecarConfiguration(ISidecarConfiguration):
                "virtual_network_id={} " \
                "environment={} " \
                "provider={} " \
+               "internet_facing={} " \
                "sandbox_id={} " \
                "production_id={} " \
                "space_id={} " \
@@ -338,6 +354,7 @@ class AwsSidecarConfiguration(ISidecarConfiguration):
                                            self.virtual_network_id,
                                            self.environment,
                                            self.provider,
+                                           self.internet_facing,
                                            self.sandbox_id,
                                            self.production_id,
                                            self.space_id,
@@ -359,11 +376,13 @@ class KubernetesSidecarConfiguration(ISidecarConfiguration):
                  apps: List[SidecarApplication],
                  services: List[ISidecarService],
                  messaging: MessagingConnectionProperties,
-                 env_type: str):
+                 env_type: str,
+                 internet_facing: bool = True):
         super().__init__(environment, "kubernetes", sandbox_id, production_id, space_id, cloud_external_key, apps,
                          services,
                          messaging,
-                         env_type)
+                         env_type,
+                         internet_facing)
         self.kub_api_address = kub_api_address
 
     def __eq__(self, other):
@@ -382,6 +401,7 @@ class KubernetesSidecarConfiguration(ISidecarConfiguration):
         return "kub_api_address={} " \
                "environment={} " \
                "provider={} " \
+               "internet_facing={} " \
                "sandbox_id={} " \
                "production_id={} " \
                "space_id={} " \
@@ -391,6 +411,7 @@ class KubernetesSidecarConfiguration(ISidecarConfiguration):
                "messaging={}".format(self.kub_api_address,
                                      self.environment,
                                      self.provider,
+                                     self.internet_facing,
                                      self.sandbox_id,
                                      self.production_id,
                                      self.space_id,
