@@ -8,17 +8,8 @@ from sidecar.model.objects import AwsSidecarConfiguration, AzureSidecarConfigura
 
 
 class MessagingConnectionPropertiesSchema(Schema):
-    queue = fields.Str()
-    usessl = fields.Boolean()
-    expires = fields.Integer()
-    queuetype = fields.Str()
-    port = fields.Integer()
-    virtualhost = fields.Str()
-    routingkey = fields.Str()
+    address = fields.Str()
     exchange = fields.Str()
-    password = fields.Str()
-    user = fields.Str()
-    host = fields.Str()
 
     @post_load
     def make(self, data):
@@ -126,6 +117,7 @@ class SidecarConfigurationSchema(Schema):
     services = fields.List(fields.Nested(SidecarServiceSchema()))
     messaging = fields.Nested(MessagingConnectionPropertiesSchema(), required=True)
     env_type = fields.Str()
+    internet_facing = fields.Bool(required=True)
 
     @post_load
     def make(self, data):
@@ -160,6 +152,7 @@ class AwsSidecarConfigurationSchema(SidecarConfigurationSchema):
     onboarding_region = fields.Str(allow_none=True)
     data_table_name = fields.Str()
     virtual_network_id = fields.Str()
+    infra_stack_name = fields.Str(allow_none=True)
 
     @post_load
     def make(self, data):
@@ -172,12 +165,14 @@ class AwsSidecarConfigurationSchema(SidecarConfigurationSchema):
 
 
 class AzureSidecarConfigurationSchema(SidecarConfigurationSchema):
-    tenant_id = fields.Str()
-    application_secret = fields.Str()
-    application_id = fields.Str()
+    tenant_id = fields.Str(required=False, allow_none=True)
+    application_secret = fields.Str(required=False, allow_none=True)
+    application_id = fields.Str(required=False, allow_none=True)
     subscription_id = fields.Str()
     management_resource_group = fields.Str()
     vnet_name = fields.Str()
+    managed_identity_client_id = fields.Str(required=False, allow_none=True)
+
     @post_load
     def make(self, data):
         super().make(data)
