@@ -1,3 +1,4 @@
+import base64
 import logging.config
 import os
 import sys
@@ -5,7 +6,6 @@ import traceback
 from datetime import datetime
 from logging import Logger
 
-import requests
 from blinker import Namespace
 from blinker import signal
 from flask import Flask, request, Request
@@ -35,7 +35,7 @@ from sidecar.cloud_logger.logs import AppLogEntry
 from sidecar.configuration_start_policy import ConfigurationStartPolicy
 from sidecar.const import Const, DateTimeProvider, Signals
 from sidecar.file_system import FileSystemService
-from sidecar.filters import LoggingFilter
+from sidecar.filters import LoggingFilter, LogConfigData
 from sidecar.health_check.app_health_check_monitor import AppHealthCheckMonitor, AppHealthCheckConfiguration
 from sidecar.health_check.app_health_check_state import AppHealthCheckState
 from sidecar.health_check.app_instance_health_check_monitor import AppInstanceHealthCheckMonitor
@@ -60,6 +60,7 @@ from sidecar.sandbox_deployment_state_tracker import SandboxDeploymentStateTrack
 from sidecar.sandbox_end_deployment_notifier import SandboxEndDeploymentNotifier
 from sidecar.sandbox_error import SandboxError
 from sidecar.sandbox_start_time_updater import ISandboxStartTimeUpdater
+from sidecar.service_termination_start_policy import ServiceTerminationStartPolicy
 from sidecar.services.exceptions import NotReadyYetError
 from sidecar.services.input_resolver import InputResolver
 from sidecar.services.metadata.aws_virtual_network_fetcher import AwsVirtualNetworkFetcher
@@ -80,6 +81,8 @@ cloud_logger = None  # type: ICloudLogger
 _request_logger = None  # type: RequestLogger
 _app_instance_health_check_monitor = None  # type: AppInstanceHealthCheckMonitor
 _configuration_start_policy = None  # type: ConfigurationStartPolicy
+_service_termination_start_policy: ServiceTerminationStartPolicy = None
+
 _app_instance_identifier_creator = None  # type: IAppInstanceIdentifierCreator
 _app_instance_event_handler = None  # type: AppInstanceEventHandler
 _app_signals = Namespace()
@@ -109,7 +112,6 @@ _input_resolver = None  # type: InputResolver
 def initiate_services(config: ISidecarConfiguration,
                       app_instance_event_handler: AppInstanceEventHandler,
                       aws_session: AwsSession,
-                      own_public_ip: str,
                       sandbox_metadata_resolver: SandboxMetadataResolver) -> SandboxDeploymentStateTracker:
     global _kub_token_provider
     global _start_time_updater
@@ -119,6 +121,7 @@ def initiate_services(config: ISidecarConfiguration,
     global _app_status_maintainer
     global _app_instance_identifier_creator
     global _configuration_start_policy
+    global _service_termination_start_policy
     global _service_file_store
     global _file_logger
     global _service_status_state
@@ -130,6 +133,8 @@ def initiate_services(config: ISidecarConfiguration,
     global _app_instance_service
 
     _service_status_state = ServiceStatusState(services=config.services)
+    _service_termination_start_policy = ServiceTerminationStartPolicy(services=config.services,
+                                                                      service_status_state=_service_status_state)
 
     app_instance_status_event_reporter = AppInstanceConfigStatusEventReporter(
         app_instance_event_handler=app_instance_event_handler, logger=_logger)
@@ -185,7 +190,7 @@ def initiate_services(config: ISidecarConfiguration,
                                         app_instance_service=_app_instance_service,
                                         logger=_logger)
 
-        _app_service = K8sAppService(api=kas, sandbox_id=k8s_config.sandbox_id, own_public_ip=own_public_ip,
+        _app_service = K8sAppService(api=kas, sandbox_id=k8s_config.sandbox_id,
                                      logger=_logger, k8s_status_maintainer=_status_maintainer)
         _start_time_updater = KubSandboxStartTimeUpdater(
             app_health_check_state=_app_health_check_state,
@@ -274,7 +279,6 @@ def initiate_services(config: ISidecarConfiguration,
                                      aws_status_maintainer=aws_status_maintainer,
                                      sandbox_id=aws_config.sandbox_id,
                                      production_id=aws_config.production_id,
-                                     own_public_ip=own_public_ip,
                                      env_type=EnvironmentType.Sandbox,
                                      logger=_logger,
                                      default_region=aws_config.onboarding_region,
@@ -496,6 +500,12 @@ def update_service_status(service: str):
     return '', 200
 
 
+@flask.route("/services/<string:service>/can_start_termination", methods=['GET'])
+def can_start_termination(service: str):
+    response = _service_termination_start_policy.can_start_termination_process(service_name=service)
+    return str(response), 200
+
+
 @flask.route("/services/<string:service>/<string:cmd>/save-output", methods=['POST'])
 def save_service_execution_output(service: str, cmd: str):
     req = request  # type: Request
@@ -585,7 +595,7 @@ def get_app_health_check_configuration(config: ISidecarConfiguration) -> AppHeal
     return app_health_check_configuration
 
 
-def run_impl(config: ISidecarConfiguration, own_public_ip: str):
+def run_impl(config: ISidecarConfiguration):
     global _app_instance_health_check_monitor
     global cloud_logger
     global _app_instance_event_handler
@@ -620,7 +630,6 @@ def run_impl(config: ISidecarConfiguration, own_public_ip: str):
         config=config,
         app_instance_event_handler=_app_instance_event_handler,
         aws_session=aws_session,
-        own_public_ip=own_public_ip,
         sandbox_metadata_resolver=sandbox_metadata_resolver)
 
     _deployment_outputs_writer = DeploymentOutputsWriter(_logger,
@@ -670,7 +679,8 @@ def run_impl(config: ISidecarConfiguration, own_public_ip: str):
                                                       app_service=_app_service,
                                                       health_check_configuration=health_check_configuration,
                                                       apps_configuration_end_tracker=_apps_configuration_end_tracker,
-                                                      logger=_logger)
+                                                      logger=_logger,
+                                                      internet_facing=config.internet_facing)
 
     messaging_service = MessagingService(config.messaging, _logger)
 
@@ -680,7 +690,8 @@ def run_impl(config: ISidecarConfiguration, own_public_ip: str):
                                                                         config.space_id,
                                                                         config.sandbox_id,
                                                                         config.production_id,
-                                                                        config.env_type)
+                                                                        config.env_type,
+                                                                        _logger)
 
     on_instance_update_status_signal = signal(Signals.ON_INSTANCE_UPDATE_STATUS)
     on_instance_update_status_signal.connect(on_instance_update_status, sender=_app_status_maintainer)
@@ -703,10 +714,12 @@ def configure_debug():
 
     global _config
 
-    properties = MessagingConnectionProperties(host="wombat.rmq.cloudamqp.com", user="rhpjvtoj",
-                                               password="M7dZ2D5hWkIEOLPj6poiB4fF1t9cmNIf", queue="nefmwtza4r121",
-                                               exchange="", routingkey="nefmwtza4r121", virtualhost="rhpjvtoj",
-                                               port=5672, queuetype="fanout", expires=60000, usessl=False)
+    address = "https://rhpjvtoj:M7dZ2D5hWkIEOLPj6poiB4fF1t9cmNIf@wombat.rmq.cloudamqp.com/rhpjvtoj"
+    base64_bytes = base64.b64encode(address.encode('unicode'))
+    address_base64 = base64_bytes.decode('ascii')
+
+    properties = MessagingConnectionProperties(address=address_base64,
+                                               exchange="nefmwtza4r121")
 
     application = SidecarApplication(name="fasty", instances_count=1, dependencies=[],
                                      env={"WELCOME_STRING": "Welcome to Quali Colony!", "PORT": "3001"},
@@ -753,6 +766,7 @@ def configure_debug():
                                       env_type="sandbox",
                                       production_id="",
                                       data_table_name="",
+                                      infra_stack_name=''
                                       )
 
     # _config = AzureSidecarConfiguration(
@@ -770,7 +784,8 @@ def configure_debug():
     #     services=[],
     #     messaging=properties,
     #     env_type="sandbox",
-    #     virtual_network_id='c'
+    #     vnet_name='c',
+    #     managed_identity_client_id='5817a28e-95a8-4fae-928e-501fd62f7058'
     # )
 
 
@@ -782,6 +797,25 @@ def get_build_info_json():
         return build_info__json
 
 
+def read_configuration() -> ISidecarConfiguration:
+    global _logger
+
+    config_data = {}
+    try:
+        with open(Const.get_config_file(), 'r') as conf:
+            config_data = json.loads(conf.read())
+            return SidecarConfigurationFactory.get(config_data)
+    except Exception as exc:
+        # even if config_data is empty, the filter will still add some useful properties like 'colony.hostname'
+        _logger.addFilter(LoggingFilter(LogConfigData(
+            environment=config_data.get('environment'),
+            sandbox_id=config_data.get('sandbox_id'),
+            production_id=config_data.get('production_id')
+        )))
+        _logger.exception("sidecar failed to start - failed to load configuration")
+        raise exc
+
+
 def run():
     global _config
     global _logger
@@ -791,12 +825,15 @@ def run():
     logging.config.fileConfig(os.path.join(dir_name, 'logzio.conf'))
     _logger = logging.getLogger("logger")
 
-    try:
-        if _config is None:
-            with open(Const.get_config_file(), 'r') as conf:
-                _config = SidecarConfigurationFactory.get(json.loads(conf.read()))
+    if _config is None:
+        _config = read_configuration()
 
-        _logger.addFilter(LoggingFilter(_config))
+    try:
+        _logger.addFilter(LoggingFilter(LogConfigData(
+            environment=_config.environment,
+            sandbox_id=_config.sandbox_id,
+            production_id=_config.production_id
+        )))
         _request_logger = RequestLogger(flask, _logger, [write_log])
         CallsLogger.set_logger(_logger)
 
@@ -804,7 +841,7 @@ def run():
         _logger.info('build_info.json: {}'.format(json.dumps(get_build_info_json())))
         _logger.info('config.json: {}'.format(_config))
 
-        run_impl(config=_config, own_public_ip=_get_own_ip())
+        run_impl(config=_config)
 
         flask.run(host='0.0.0.0', port=4000)
 
@@ -813,26 +850,6 @@ def run():
         raise exc
 
 
-def _get_own_ip() -> str:
-    sources = (
-        "http://icanhazip.com",
-        "http://ident.me",
-        "http://whatismyip.akamai.com",
-        "http://ip.tyk.nu",
-        "http://wgetip.com"
-    )
-
-    for source in sources:
-        try:
-            resp = requests.get(source)
-            if resp.status_code == 200:
-                return resp.text.replace(' ', '').replace('\n', '').replace('\t', '')
-        except:
-            pass
-
-    raise ConnectionError("Could not retrieve own IP from defined sources.")
-
-
 def get_remote_address():
     if isinstance(_kub_token_provider, FakeKubTokenProvider):  # debug mode
         return request.headers.getlist("X-Forwarded-For")[0]
