@@ -8,6 +8,7 @@ import requests
 import time
 
 from sidecar.const import Const
+import multiprocessing.pool
 
 
 class Utils:
@@ -138,3 +139,30 @@ class CallsLogger:
                     cls.logger.info(func.__qualname__ + "(" + ", ".join(args_list) + ") -> "+result_str)
 
         return decorator
+
+
+class TimeoutUtils:
+    # This is the Timeout decorator.
+    # Example of use:
+    #
+    # import TimeoutUtils
+    # ....
+    #
+    # @TimeoutUtils.timeout(2)
+    # def myFunc:
+    # ....
+    #
+    @staticmethod
+    def timeout(timeout_in_seconds: int):
+        def timeout_decorator(func):
+            def func_wrapper(*args, **kwargs):
+                pool = multiprocessing.pool.ThreadPool(processes=1)
+                async_result = pool.apply_async(func, args, kwargs)
+                try:
+                    return async_result.get(timeout_in_seconds)
+                except Exception as ex:
+                    raise ex
+                finally:
+                    pool.close()
+            return func_wrapper
+        return timeout_decorator
